@@ -16,22 +16,16 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
-const Params = imports.params;
-const Pango = imports.gi.Pango;
+const {GLib, GObject, Gtk} = imports.gi;
 
-var MenuPopover = new Lang.Class({
-    Name: 'MenuPopover',
-    Extends: Gtk.Popover,
+const Params = imports.params;
+
+var MenuPopover = GObject.registerClass({
     Template: 'resource:///org/gnome/Characters/menu.ui',
     InternalChildren: ['search-entry', 'font-listbox'],
-
-    _createFontListRow: function(title, family) {
-        let row = new Gtk.ListBoxRow({ visible: true });
+}, class MenuPopover extends Gtk.Popover {
+    _createFontListRow(title, family) {
+        const row = new Gtk.ListBoxRow({ visible: true });
         row.get_style_context().add_class('font');
         row._family = family;
         let label = new Gtk.Label({ label: title,
@@ -40,11 +34,11 @@ var MenuPopover = new Lang.Class({
         label.get_style_context().add_class('font-label');
         row.add(label);
         return row;
-    },
+    }
 
-    _init: function(params) {
+    _init(params) {
         params = Params.fill(params, {});
-        this.parent(params);
+        super._init(params);
 
         this._font_listbox.get_style_context().add_class('fonts');
         let row = this._createFontListRow(_("None"), 'None');
@@ -62,12 +56,10 @@ var MenuPopover = new Lang.Class({
         }
 
         this._keywords = [];
-        this._search_entry.connect('search-changed',
-                                   Lang.bind(this, this._handleSearchChanged));
-        this._font_listbox.connect('row-activated',
-                                   Lang.bind(this, this._handleRowActivated));
-        this._font_listbox.set_filter_func(Lang.bind(this, this._filterFunc));
-        this._font_listbox.set_header_func(Lang.bind(this, this._headerFunc));
+        this._search_entry.connect('search-changed', (entry) => this._handleSearchChanged(entry));
+        this._font_listbox.connect('row-activated', (listBox, row) => this._handleRowActivated(listBox, row));
+        this._font_listbox.set_filter_func((row) => this._filterFunc(row));
+        this._font_listbox.set_header_func((row, before) => this._headerFunc(row, before));
 
         // This silents warning at Characters exit about this widget being
         // visible but not mapped.  Borrowed from Maps.
@@ -75,25 +67,25 @@ var MenuPopover = new Lang.Class({
             popover._font_listbox.unselect_all();
             popover.hide();
         });
-    },
+    }
 
-    _handleSearchChanged: function(entry) {
+    _handleSearchChanged(entry) {
         let text = entry.get_text().replace(/^\s+|\s+$/g, '');
         let keywords = text == '' ? [] : text.split(/\s+/);
         this._keywords = keywords.map(String.toLowerCase);
         this._font_listbox.invalidate_filter();
         return true;
-    },
+    }
 
-    _handleRowActivated: function(listBox, row) {
+    _handleRowActivated(listBox, row) {
         if (row != null) {
             let toplevel = this.get_toplevel();
             let action = toplevel.lookup_action('filter-font');
             action.activate(new GLib.Variant('s', row._family));
         }
-    },
+    }
 
-    _filterFunc: function(row) {
+    _filterFunc(row) {
         if (this._keywords.length == 0)
             return true;
         if (row._family == 'None')
@@ -105,9 +97,9 @@ var MenuPopover = new Lang.Class({
                 return nameWord.indexOf(keyword) >= 0;
             });
         });
-    },
+    }
 
-    _headerFunc: function(row, before) {
+    _headerFunc(row, before) {
         if (before && !row.get_header()) {
             let separator = new Gtk.Separator({
                 orientation: Gtk.Orientation.HORIZONTAL
